	SUBROUTINE AC_BFIF  ( iubfma, iret )
C************************************************************************
C* AC_BFIF								*
C*									*
C* This subroutine decodes a report from an ARINC ACARS BUFR message,	*
C* converts it into interface output, and then writes the interface	*
C* output into the interface arrays.					*
C*									*
C* AC_BFIF  ( IUBFMA, IRET )						*
C*									*
C* Input parameters:							*
C*	IUBFMA		INTEGER		Logical unit number of ARINC	*
C*					ACARS BUFR messages file	*
C* Output parameters:							*
C*	RIVALS (IRYEAR)	REAL		Report year			*
C*	RIVALS (IRMNTH)	REAL		Report month			*
C*	RIVALS (IRDAYS)	REAL		Report day			*
C*	RIVALS (IRHOUR)	REAL		Report hour			*
C*	RIVALS (IRMINU)	REAL		Report minute			*
C*	RIVALS (IRSECO)	REAL		Report second			*
C*	CIVALS (ICACID)	CHAR*8		Aircraft flight number		*
C*					  (encrypted by ARINC)		*
C*	CIVALS (ICACRN)	CHAR*8		Aircraft registration number	*
C*					  (encrypted by ARINC)		*
C*	CIVALS (ICARST)	CHAR*8		ARINC ground receiving station	*
C*	RIVALS (IRSLAT)	REAL		Latitude in degrees		*
C*	RIVALS (IRSLON)	REAL		Longitude in degrees		*
C*	RIVALS (IROSLL)	REAL		Orig. specification of lat/long	*
C*					  (WMO BUFR Table 0 02 070)	*
C*	RIVALS (IRPRES)	REAL		Pressure in millibars		*
C*	RIVALS (IRIALT)	REAL		Aircraft altitude in meters	*
C*	RIVALS (IRTMPK)	REAL		Temperature in Kelvin		*
C*	RIVALS (IRPCAT)	REAL		Temperature precision in Kelvin	*
C*	RIVALS (IRDRCT)	REAL		Wind direction in degrees true	*
C*	RIVALS (IRSPED)	REAL		Wind speed in m/s		*
C*	RIVALS (IRTIWM)	REAL		Wind measurement instrument type*
C*					  (WMO BUFR Table 0 02 002)	*
C*	RIVALS (IRPOAF)	REAL		Phase of aircraft flight	*
C*					  (WMO BUFR Table 0 08 004)	*
C*	RIVALS (IRTADR)	REAL		Aircraft data relay system type	*
C*					  (WMO BUFR Table 0 02 062)	*
C*	RIVALS (IRTOST)	REAL		Station type			*
C*					  (WMO BUFR Table 0 02 001)	*
C*	RIVALS (IRROLQ)	REAL		Aircraft roll angle quality	*
C*					  (WMO BUFR Table 0 02 064)	*
C*	RIVALS (IRINTV)	REAL		ACARS interpolated values	*
C*					  (WMO BUFR Table 0 33 025)	*
C*	RIVALS (IRMIXR)	REAL		Mixing ratio in kg/kg		*
C*	RIVALS (IRMSTQ)	REAL		Moisture quality		*
C*					  (WMO BUFR Table 0 33 026)	*
C*	RIVALS (IRRELH)	REAL		Relative humidity in %		*
C*	RIVALS(IRTRBX10)REAL		Turbulence index for period	*
C*					(TOB-1 min) -> TOB		*
C*	RIVALS(IRTRBX21)REAL		Turbulence index for period	*
C*					(TOB-2 min) -> (TOB-1 min)	*
C*	RIVALS(IRTRBX32)REAL		Turbulence index for period	*
C*					(TOB-3 min) -> (TOB-2 min)	*
C*	RIVALS(IRTRBX43)REAL		Turbulence index for period	*
C*					(TOB-4 min) -> (TOB-3 min)	*
C*	IRET		INTEGER		Return code:			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* J. Ator/NCEP		06/97						*
C* J. Ator/NCEP		01/98	New interface format, style changes	*
C* R. Hollern/NCEP	05/00	Added turbulence index logic            *
C* J. Ator/NCEP		09/00	Removed "GEMINC:" prefix from INCLUDEs	*
C*				changes for new ARINC format		*
C* J. Ator/NCEP		06/01	Clean up				*
C* J. Ator/NCEP		02/05	TMDB -> TMDBST				*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	INCLUDE		'accmn.cmn'
C*
	PARAMETER	( NTRBX = 4 )
C*
        REAL*8		r8trbx ( NTRBX )
C*-----------------------------------------------------------------------
	iret = 0
C
	CALL UT_BFCI  ( iubfma, 'ACID', civals ( icacid ), ierbci )
	CALL UT_BFCI  ( iubfma, 'ACRN', civals ( icacrn ), ierbci )
	CALL UT_BFCI  ( iubfma, 'ARST', civals ( icarst ), ierbci )
C
	CALL UT_BFRI  ( iubfma, 'YEAR', rivals ( iryear ), ierbri )
	CALL UT_BFRI  ( iubfma, 'MNTH', rivals ( irmnth ), ierbri )
	CALL UT_BFRI  ( iubfma, 'DAYS', rivals ( irdays ), ierbri )
	CALL UT_BFRI  ( iubfma, 'HOUR', rivals ( irhour ), ierbri )
	CALL UT_BFRI  ( iubfma, 'MINU', rivals ( irminu ), ierbri )
	CALL UT_BFRI  ( iubfma, 'SECO', rivals ( irseco ), ierbri )
	CALL UT_BFRI  ( iubfma, 'CLAT', rivals ( irslat ), ierbri )
	CALL UT_BFRI  ( iubfma, 'CLON', rivals ( irslon ), ierbri )
	CALL UT_BFRI  ( iubfma, 'OSLL', rivals ( irosll ), ierbri )
	CALL UT_BFRI  ( iubfma, 'IALT', rivals ( irialt ), ierbri )
	CALL UT_BFRI  ( iubfma, 'TMDBST', rivals ( irtmpk ), ierbri )
	CALL UT_BFRI  ( iubfma, 'PCAT', rivals ( irpcat ), ierbri )
	CALL UT_BFRI  ( iubfma, 'WDIR', rivals ( irdrct ), ierbri )
	CALL UT_BFRI  ( iubfma, 'WSPD', rivals ( irsped ), ierbri )
	CALL UT_BFRI  ( iubfma, 'TIWM', rivals ( irtiwm ), ierbri )
	CALL UT_BFRI  ( iubfma, 'POAF', rivals ( irpoaf ), ierbri )
	CALL UT_BFRI  ( iubfma, 'TADR', rivals ( irtadr ), ierbri )
	CALL UT_BFRI  ( iubfma, 'TOST', rivals ( irtost ), ierbri )
	CALL UT_BFRI  ( iubfma, 'ROLQ', rivals ( irrolq ), ierbri )
	CALL UT_BFRI  ( iubfma, 'INTV', rivals ( irintv ), ierbri )
	CALL UT_BFRI  ( iubfma, 'MIXR', rivals ( irmixr ), ierbri )
	CALL UT_BFRI  ( iubfma, 'MSTQ', rivals ( irmstq ), ierbri )
	CALL UT_BFRI  ( iubfma, 'REHU', rivals ( irrelh ), ierbri )
C
	CALL UT_BFRI  ( iubfma, 'PRLC', prlc, ierbri )
	rivals ( irpres ) = PR_D100 ( prlc )
C
C*	Unpack and check the time increment value.
C
	CALL UT_BFRI  ( iubfma, 'TIMI', timi, ierbri )
	itimi = INT ( timi )
	IF  ( itimi .ne. -1 )  THEN
	    WRITE  ( UNIT = logmsg, FMT = '(A, I5)' )
     +		'Unexpected TIMI value of ', itimi
	    CALL DC_WLOG  ( 2, 'DC', 2, logmsg, ierwlg )
	    RETURN
	END IF
C
C*	Unpack and check the time duration values.
C
	CALL UFBREP  ( iubfma, r8trbx, 1, NTRBX, ierufb, '.DTMTRBX' )
	DO jj = 1, NTRBX
	    idtrbx = INT ( UT_BMRI ( r8trbx (jj) ) )
	    IF  ( idtrbx .ne. 1 )  THEN
		WRITE  ( UNIT = logmsg, FMT = '(A, I5, A, I2)' )
     +		    'Unexpected .DTMTRBX value of ', idtrbx, 
     +		    ' at position', jj 
		CALL DC_WLOG  ( 2, 'DC', 2, logmsg, ierwlg )
		RETURN
	    END IF
	END DO 
C
C*	Decode and store the turbulence data.
C
	CALL UFBREP  ( iubfma, r8trbx, 1, NTRBX, ierufb, 'TRBX' )
	rivals ( irtrbx10 ) = UT_BMRI ( r8trbx (1) )
	rivals ( irtrbx21 ) = UT_BMRI ( r8trbx (2) )
	rivals ( irtrbx32 ) = UT_BMRI ( r8trbx (3) )
	rivals ( irtrbx43 ) = UT_BMRI ( r8trbx (4) )
C*
        RETURN
	END
